# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/01_algorithm.ipynb.

# %% ../nbs/01_algorithm.ipynb 2
from __future__ import annotations

# %% auto 0
__all__ = ['bar']

# %% ../nbs/01_algorithm.ipynb 5
def bar(): pass



# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/',
                'doc_host': 'https://docs.gograph.org',
                'git_url': 'https://github.com/rossheat/gograph',
                'lib_path': 'gograph'},
  'syms': { 'gograph.algorithm': {'gograph.algorithm.bar': ('algorithm.html#bar', 'gograph/algorithm.py')},
            'gograph.core': {'gograph.core.foo': ('core.html#foo', 'gograph/core.py')},
            'gograph.graph': { 'gograph.graph.Graph': ('graph.html#graph', 'gograph/graph.py'),
                               'gograph.graph.Graph.__init__': ('graph.html#__init__', 'gograph/graph.py'),
                               'gograph.graph.Graph.n_vertices': ('graph.html#graph.n_vertices', 'gograph/graph.py'),
                               'gograph.graph.Graph.say_hello': ('graph.html#graph.say_hello', 'gograph/graph.py'),
                               'gograph.graph.print_hello': ('graph.html#print_hello', 'gograph/graph.py')}}}


# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_graph.ipynb.

# %% ../nbs/00_graph.ipynb 2
from __future__ import annotations
from fastcore.all import * 

# %% auto 0
__all__ = ['Graph', 'print_hello']

# %% ../nbs/00_graph.ipynb 6
class Graph: 
    "A graph."
    def __init__(self, 
                 vertices: list[str], # The vertices
                 edges: list[str] # The egdes
                ) -> None:
        self.vertices = vertices
        self.edges = edges

# %% ../nbs/00_graph.ipynb 7
@patch 
def n_vertices(self: Graph) -> int: 
    "Return number of verticles."
    return len(self.vertices)

# %% ../nbs/00_graph.ipynb 8
@patch
def say_hello(
    self: Graph, 
    to: str # The person to say hello to 
)-> str: 
    return f"Hello {to}"

# %% ../nbs/00_graph.ipynb 11
def print_hello(): 
    print("hello")
